@@ -12,9 +12,18 @@ import pandas as pd
 from connectome import Source, meta
 from connectome.interface.nodes import Silent, Output
 
-from .internals import checksum
+from .internals import checksum, register
 
 
+@register(
+    body_region='Head',
+    license='CC BY-NC-SA 4.0',
+    link='https://zenodo.org/record/6504722#.YsgwnNJByV4',
+    modality=('MRI T1c', 'MRI T2hr'),
+    prep_data_size=None,  # TODO: should be measured...
+    raw_data_size='17G',
+    task=('Segmentation', 'Classification', 'Domain Adaptation'),
+)
 @checksum('crossmoda2022')
 class CrossMoDA(Source):
     """
@@ -55,20 +64,20 @@ class CrossMoDA(Source):
         for archive in Path(_root).glob('*.zip'):
             with ZipFile(archive) as zf:
                 for zipinfo in zf.infolist():
-                    
+
                     if zipinfo.is_dir():
                         continue
-                    
+
                     file = Path(zipinfo.filename)
                     assert file.stem not in result, file.stem
-                
+
                     if 'Label' not in file.stem and file.suffix == '.gz':
                         result.add('_'.join(file.stem.split('_')[:-1]))
                     else:
                         continue
 
         return sorted(result)
-    
+
     @meta
     def train_source_df(_root):
         return pd.read_csv(Path(_root) / 'infos_source_training.csv', index_col='crossmoda_name')
@@ -77,7 +86,7 @@ class CrossMoDA(Source):
         for archive in Path(_root).glob('*.zip'):
             with ZipFile(archive) as zf:
                 for zipinfo in zf.infolist():
-                    if i == '_'.join(Path(zipinfo.filename).stem.split('_')[:-1]):
+                    if i == '_'.join(Path(zipinfo.filename).stem.split('_')[:-1]) and 'Label' not in zipinfo.filename:
                         return zipfile.Path(archive, zipinfo.filename)
 
         raise ValueError(f'Id "{i}" not found')
@@ -111,7 +120,7 @@ class CrossMoDA(Source):
         """ The split in which this entry is contained: training_source, training_target, validation """
         idx = int(_file.name.split('_')[2])
         dataset = _file.name.split('_')[1]
-        
+
         if dataset == 'ldn':
             if 1 <= idx < 106:
                 return 'training_source'
@@ -119,15 +128,15 @@ class CrossMoDA(Source):
                 return 'training_target'
             elif 211 <= idx < 243:
                 return 'validation'
-            
+
         elif dataset == 'etz':
-            if 1 <= idx < 105:
+            if 0 <= idx < 105:
                 return 'training_source'
             elif 105 <= idx < 210:
                 return 'training_target'
-            elif 211 <= idx < 242:
+            elif 210 <= idx < 242:
                 return 'validation'
-            
+
         raise ValueError(f'Cannot find split for the file: {_file}')
 
     def year(_file) -> int:
@@ -144,6 +153,8 @@ class CrossMoDA(Source):
                 mask = nibabel.Nifti1Image.from_file_map({'header': nii, 'image': nii})
                 return mask.get_fdata().astype(np.uint8)
 
-    def koos_grade(i, train_source_df: Output) -> int:
+    def koos_grade(i, train_source_df: Output, split: Output) -> int:
         """ VS Tumour characteristic according to Koos grading scale: [1..4] or (-1 - post operative) """
-        return (lambda x: -1 if x == 'post-operative-london' else int(x))(train_source_df.loc[i, 'koos'])
\ No newline at end of file
+        if split != 'training_source':
+            return None
+        return (lambda x: -1 if x == 'post-operative-london' else int(x))(train_source_df.loc[i, 'koos'])
