@@ -15,9 +15,9 @@ class CacheToDisk(Disk):
     def __init__(self, names: StringsLike, serializer: Union[Serializer, Sequence[Serializer]] = None,
                  fetch: bool = False, **kwargs):
         repo = Repository.from_here('../data')
-        local, remote = repo.cache
+        cache = repo.cache
         super().__init__(
-            [x.root for x in local[0].locations], repo.storage, remote=remote if fetch else [],
+            [x.root for x in cache.local[0].locations], cache.storage, remote=cache.remote if fetch else [],
             serializer=default_serializer(serializer), names=names, **kwargs
         )
 
