@@ -13,7 +13,13 @@ from connectome.interface.nodes import Silent
 from .internals import checksum, register
 
 
-@register()
+@register(
+    body_region='Thorax, Abdomen',
+    modality='CT',
+    task='Vertebrae Segmentation',
+    link='https://osf.io/4skx2/',
+    raw_data_size='97G',
+)
 @checksum('verse')
 class VerSe(Source):
     """
@@ -32,8 +38,8 @@ class VerSe(Source):
     Notes
     -----
     Download links:
-    2019: https://osf.io/jtfa5/
-    2020: https://osf.io/4skx2/
+        2019: https://osf.io/jtfa5/
+        2020: https://osf.io/4skx2/
 
     Examples
     --------
